@@ -7,12 +7,12 @@ from sapiopylib.rest.User import SapioUser
 from sapiopylib.rest.pojo.CustomReport import RawReportTerm, RawTermOperation
 from sapiopylib.rest.pojo.datatype.FieldDefinition import VeloxIntegerFieldDefinition, VeloxStringFieldDefinition, \
     AbstractVeloxFieldDefinition
-from sapiopylib.rest.pojo.webhook.WebhookContext import SapioWebhookContext
-from sapiopylib.rest.pojo.webhook.WebhookResult import SapioWebhookResult
 
 from sapiopycommons.callbacks.callback_util import CallbackUtil
 from sapiopycommons.files.file_data_handler import FileDataHandler, FilterList
+from sapiopycommons.general.aliases import UserIdentifier, AliasUtil
 from sapiopycommons.general.custom_report_util import CustomReportUtil
+from sapiopycommons.general.exceptions import SapioUserCancelledException
 from sapiopycommons.general.time_util import TimeUtil
 
 
@@ -80,10 +80,10 @@ class FileValidator:
 
         return failed_rows
 
-    def build_violation_report(self, context: SapioWebhookResult | SapioUser,
+    def build_violation_report(self, context: UserIdentifier,
                                rule_violations: dict[int, list[ValidationRule]]) -> None:
         """
-        Build a simple report of any rule violations in the file to display to the user as a table dialog.
+        Display a simple report of any rule violations in the file to the user as a table dialog.
 
         :param context: The current webhook context or a user object to send requests from.
         :param rule_violations: A dict of rule violations generated by a call to validate_file.
@@ -121,9 +121,24 @@ class FileValidator:
                         "Reason": violation.reason[:2000]
                     })
 
-        callback_util = CallbackUtil(context)
-        callback_util.table_dialog("Errors", "The following rule violations were encountered in the provided file.",
-                                   columns, rows)
+        callback = CallbackUtil(context)
+        callback.table_dialog("Errors", "The following rule violations were encountered in the provided file.",
+                              columns, rows)
+
+    def validate_and_report_errors(self, context: UserIdentifier) -> None:
+        """
+        Validate the file. If any rule violations are found, display a simple report of any rule violations in the file
+        to the user as a table dialog and throw a SapioUserCancelled exception after the user acknowledges the dialog
+        to end the webhook interaction.
+
+        Shorthand for calling validate_file() and then build_violation_report() if there are any errors.
+
+        :param context: The current webhook context or a user object to send requests from.
+        """
+        violations = self.validate_file()
+        if violations:
+            self.build_violation_report(context, violations)
+            raise SapioUserCancelledException()
 
 
 class ValidationRule:
@@ -494,7 +509,7 @@ class UniqueSystemValueRule(ColumnRule):
     data_type_name: str
     data_field_name: str
 
-    def __init__(self, context: SapioWebhookContext | SapioUser, header: str, data_type_name: str,
+    def __init__(self, context: UserIdentifier, header: str, data_type_name: str,
                  data_field_name: str):
         """
         :param context: The current webhook context or a user object to send requests from.
@@ -502,7 +517,7 @@ class UniqueSystemValueRule(ColumnRule):
         :param data_type_name: The data type name to search on.
         :param data_field_name: The data field name to search on. This is expected to be a string field.
         """
-        self.user = context.user if isinstance(context, SapioWebhookContext) else context
+        self.user = AliasUtil.to_sapio_user(context)
         self.data_type_name = data_type_name
         self.data_field_name = data_field_name
         super().__init__(header, f"This value already exists in the system.")
@@ -528,7 +543,7 @@ class ExistingSystemValueRule(ColumnRule):
     data_type_name: str
     data_field_name: str
 
-    def __init__(self, context: SapioWebhookContext | SapioUser, header: str, data_type_name: str,
+    def __init__(self, context: UserIdentifier, header: str, data_type_name: str,
                  data_field_name: str):
         """
         :param context: The current webhook context or a user object to send requests from.
@@ -536,7 +551,7 @@ class ExistingSystemValueRule(ColumnRule):
         :param data_type_name: The data type name to search on.
         :param data_field_name: The data field name to search on. This is expected to be a string field.
         """
-        self.user = context.user if isinstance(context, SapioWebhookContext) else context
+        self.user = AliasUtil.to_sapio_user(context)
         self.data_type_name = data_type_name
         self.data_field_name = data_field_name
         super().__init__(header, f"This value doesn't exist in the system.")
